/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.cat.glossary.core;

import java.util.ArrayList;
import java.util.List;

/**
 * Benten 用語集ドライバを管理するクラス。
 */
public class BentenGlossaryDriverManager {
	/**
	 * 登録されている用語集ドライバーのリスト。
	 */
	protected static final List<BentenGlossaryDriver> fDriverList = new ArrayList<BentenGlossaryDriver>();

	/**
	 * 用語集ドライバを登録します。
	 *
	 * @param driver 登録したい用語集ドライバー。
	 */
	public static void registerDriver(final BentenGlossaryDriver driver) {
		if (driver == null) {
			throw new IllegalArgumentException("registerDriver: Illegal argument: driver must be not null.");
		}

		for (final BentenGlossaryDriver look : fDriverList) {
			if (look.getName().equals(driver.getName())) {
				// すでに登録済みのドライバーです。
				return;
			}
		}

		fDriverList.add(driver);
	}

	/**
	 * 用語集ドライバーを登録解除します。
	 *
	 * @param driver 登録解除したい用語集ドライバー。
	 */
	public static void deregisterDriver(final BentenGlossaryDriver driver) {
		if (driver == null) {
			throw new IllegalArgumentException("registerDriver: Illegal argument: driver must be not null.");
		}

		for (final BentenGlossaryDriver look : fDriverList) {
			if (look.getName().equals(driver.getName())) {
				fDriverList.remove(look);
				break;
			}
		}
	}

	/**
	 * 登録されている用語集ドライバーの一覧を取得します。
	 * 
	 * @return 用語集ドライバーの配列。
	 */
	public static BentenGlossaryDriver getDriver(final String driverName) {
		if (driverName == null) {
			throw new IllegalArgumentException("BentenGlossaryDriver#getDriver: 不正な引数: driverName は null であってはなりません。");
		}

		for (BentenGlossaryDriver driver : fDriverList) {
			if (driver.getName().equals(driverName)) {
				return driver;
			}
		}

		return null;
	}

	/**
	 * 登録されている用語集ドライバーの一覧を取得します。
	 *
	 * @return 用語集ドライバーの配列。
	 */
	public static BentenGlossaryDriver[] getDrivers() {
		final BentenGlossaryDriver[] drivers = new BentenGlossaryDriver[fDriverList.size()];
		for (int index = 0; index < fDriverList.size(); index++) {
			drivers[index] = fDriverList.get(index);
		}

		return drivers;
	}
}
