/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.cat.glossary.core;

import java.io.File;
import java.io.IOException;
import java.util.List;

/**
 * Benten 用語集エンジンをあらわすインタフェース。
 * 
 * 用語集の主たる処理は、このインタフェースを実装したクラスに記述されます。
 */
public interface BentenGlossaryEngine {
	/**
	 * TSV 形式用語集のロード。
	 * 
	 * タブ区切り形式ファイルの用語集をロードします。
	 * このメソッドを呼ぶと、追加的に用語集が構築されます。
	 * 
	 * @param dirTsv TSV 形式のファイルが格納されたディレクトリー。
	 * @throws IOException 入出力例外が発生した場合。
	 */
	void loadTsv(File dirTsv) throws IOException;

	/**
	 * 用語集のアンロード。
	 * 
	 * このエンジンが保持している用語集を破棄します。
	 */
	void unload();

	/**
	 * 用語集を検索して用語エントリーのリストを取得します。
	 * 
	 * @param search
	 *            検索したい用語。
	 * @return 用語エントリーのリスト。
	 */
	List<BentenGlossarySearchResult> search(String search);
}
