/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.cat.glossary.engine;

import benten.cat.glossary.core.BentenGlossaryEngine;
import benten.core.AbstractBentenPlugin;

/**
 * Benten 用語集エンジンのための抽象プラグイン。
 * 
 * Benten 用語集エンジン作成者は、このクラスを継承して実際の用語集エンジン・プラグインを提供する必要があります。
 * この抽象クラスを継承し、かつ拡張ポイントを提供しているものが、用語集エンジン・プラグインとして動作します。
 * このクラスの中で、Eclipse 拡張ポイントへのアクセスなどを実施します。
 */
public abstract class AbstractBentenGlossaryEnginePlugin extends AbstractBentenPlugin {

	/** 共用インスタンス */
	protected static AbstractBentenGlossaryEnginePlugin plugin;

	/**
	 * このプラグインが利用する用語集エンジンのインスタンス。
	 */
	protected BentenGlossaryEngine fEngine = null;

	/**
	 * このプラグインの共用インスタンスを取得します。
	 * 
	 * @return このプラグインの共用インスタンス
	 */
	public static AbstractBentenGlossaryEnginePlugin getDefault() {
		return plugin;
	}

	/**
	 * 用語集データをロードします。
	 * 
	 * 一般的な処理内容は以下のようになります。
	 * <UL>
	 * <LI>最初にエンジンが保持している用語集データをアンロードします。
	 * <LI>拡張ポイント登録一覧から、この用語集エンジンが処理可能な拡張ポイントを取得します。
	 * <LI>得られた拡張ポイントから処理可能な拡張のリストを取得します。
	 * <LI>拡張のリストの中で、この用語集エンジンが期待する名称の拡張を取得します。
	 * <LI>得られた拡張から、用語集データを読み込みます。
	 * </UL>
	 */
	public abstract void load();

	/**
	 * 用語集エンジンのインスタンスを取得します。
	 * 
	 * @return 用語集エンジンのインスタンス。
	 */
	public BentenGlossaryEngine getEngine() {
		return fEngine;
	}
}
